@@ -96,12 +96,7 @@ std::vector<std::vector<double> > simulateHawkes(SEXP lambda0,SEXP alpha,SEXP be
     
     
     
-    arma::mat beta_minus_alpha = m_beta_matrix- m_alpha;
-    arma::cx_vec eigval=arma::eig_gen(beta_minus_alpha);
-    arma::vec eigval_real=real(eigval);
-    if(eigval_real.min()<0){
-      stop("Unstable. beta - alpha must have eigenvalues with strictly positive real part.");
-    }
+    checkStability(m_beta_matrix,m_alpha);
     
   	double lambda_star = 0.0;
 	  
@@ -225,6 +220,9 @@ std::vector<double>  jumpMean(SEXP lambda0,SEXP alpha,SEXP beta,SEXP tau)
     arma::mat m_alpha(alpha_internal.begin(),dimension,dimension,false);
     arma::vec m_beta(beta_internal.begin(),dimension,false);
     arma::mat m_beta_matrix = diagmat(m_beta);
+    
+    checkStability(m_beta_matrix,m_alpha);
+    
     arma::mat beta_minus_alpha = m_beta_matrix- m_alpha;
     arma::mat matrixBetaMinusAlpha_inv = inv(beta_minus_alpha);
     arma::mat temp = matrixBetaMinusAlpha_inv*m_beta_matrix;
@@ -267,6 +265,8 @@ arma::mat jumpVariance(SEXP lambda0,SEXP alpha,SEXP beta,SEXP tau)
     arma::vec m_beta(beta_internal.begin(),dimension,false);
     arma::mat m_beta_matrix = diagmat(m_beta);
     
+    checkStability(m_beta_matrix,m_alpha);
+    
     arma::mat temp0 = computeC5(m_lambda0,m_alpha,m_beta_matrix,m_tau);
     arma::vec tempVec = expectedStationaryLambda(m_lambda0,m_alpha,m_beta_matrix,0);
     arma::mat temp = grandLambdaInfini(m_lambda0,m_alpha,m_beta_matrix,0)+(m_alpha*vectorToDiagonalMatrix(tempVec));
@@ -317,13 +317,22 @@ arma::mat jumpAutocorrelation(SEXP lambda0,SEXP alpha,SEXP beta,SEXP tau,SEXP la
     arma::vec m_beta(beta_internal.begin(),dimension,false);
     arma::mat m_beta_matrix = diagmat(m_beta);
     
+    checkStability(m_beta_matrix,m_alpha);
+    
+    arma::mat variance = jumpVariance(lambda0,alpha,beta,tau);
+   
+     
     arma::mat temp0 = computeC2(m_lambda0,m_alpha,m_beta_matrix,m_tau)*computeC0(m_lambda0,m_alpha,m_beta_matrix,m_lag);
     temp0 = temp0*computeC2(m_lambda0,m_alpha,m_beta_matrix,m_tau);
     arma::vec tempVec = expectedStationaryLambda(m_lambda0,m_alpha,m_beta_matrix,0);
     arma::mat temp = grandLambdaInfini(m_lambda0,m_alpha,m_beta_matrix,0)+
     (m_alpha*vectorToDiagonalMatrix(tempVec));
     res = temp0*temp;
-  
+    for (int i = 0; i < dimension; i++){
+        for (int j = 0; j < dimension; j++){
+            res(i,j)=res(i,j)/sqrt(variance(i,i)*variance(j,j));
+        }
+    }
   
   
     return res;
@@ -440,7 +449,7 @@ double  likelihoodHawkes(SEXP lambda0,SEXP alpha,SEXP beta,SEXP history)
     		}
     	}
 
-  	  res =  - m_lambda0(m) * m_T - sum;
+  	  res = res - m_lambda0(m) * m_T - sum;
   
   
     	for (int i = 0; i < as<Rcpp::NumericVector>(m_history[m]).size(); i++)
